DataTables example - Deferred loading of data

# DataTables example Deferred loading of data

When using DataTables with server-side processing, the default behaviour is to have DataTables automatically make an Ajax call and load the data, removing anything which might have already been in the table. However, this behaviour might not always be desirable when the first page of the table has already been preloaded in the HTML (which you might do to ensure accessibility or for performance reasons).

This automatic Ajax call to get the first page of data can be overridden by using the `deferLoadingDT` initialisation property. It serves two purposes, firstly to indicate that deferred loading is required, but also to tell DataTables how many records there are in the full table, in this case 57 (this allows the information element and pagination to be displayed correctly).

In the example below, the HTML page already has the first 10 rows of data available it in, so we use `deferLoadingDT` to tell DataTables that this data is available and that it should wait for under interaction (ordering, paging etc) before making an Ajax call.

"

First name | Last name | Position | Office | Start date | Salary
--- | --- | --- | --- | --- | ---
First name | Last name | Position | Office | Start date | Salary
Airi Satou | Accountant | Tokyo | 33 | 2008/11/28 | $162,700
Angelica Ramos | Chief Executive Officer (CEO) | London | 47 | 2009/10/09 | $1,200,000
Ashton Cox | Junior Technical Author | San Francisco | 66 | 2009/01/12 | $86,000
Bradley Greer | Software Engineer | London | 41 | 2012/10/13 | $132,000
Brenden Wagner | Software Engineer | San Francisco | 28 | 2011/06/07 | $206,850
Brielle Williamson | Integration Specialist | New York | 61 | 2012/12/02 | $372,000
Bruno Nash | Software Engineer | London | 38 | 2011/05/03 | $163,500
Caesar Vance | Pre-Sales Support | New York | 21 | 2011/12/12 | $106,450
Cara Stevens | Sales Assistant | New York | 46 | 2011/12/06 | $145,600
Cedric Kelly | Senior Javascript Developer | Edinburgh | 22 | 2012/03/29 | $433,060

- Javascript
- HTML
- CSS
- Ajax
- Server-side script

The Javascript shown below is used to initialise the table shown in this example:

`$(document).ready(function() { $('#example').dataTable( { "processing": true, "serverSide": true, "ajax": "scripts/server_processing.php", "deferLoading": 57 } ); } );`

In addition to the above code, the following Javascript library files are loaded for use in this example:

- ../../media/js/jquery.js
- ../../media/js/jquery.dataTables.js

The HTML shown below is the raw HTML table element, before it has been enhanced by DataTables:

This example uses a little bit of additional CSS beyond what is loaded from the library files (below), in order to correctly display the table. The additional CSS used is shown below:

``

The following CSS library files are loaded for use in this example to provide the styling of the table:

- ../../media/css/jquery.dataTables.css

This table loads data by Ajax. The latest data that has been loaded is shown below. This data will update automatically as any additional data is loaded.

The script used to perform the server-side processing for this table is shown below. Please note that this is just an example script using PHP. Server-side processing scripts can be written in any language, using the protocol described in the DataTables documentation.